==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Surveys/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","Twoje imi i nazwisko");
define("_OK","Ok!");
define("_COMMENT","komentarz");
define("_CONFIGURE","Konfiguracja");
define("_LOGINCREATE","Logowanie/Zaoenie konta");
define("_THRESHOLD","Prg");
define("_NOCOMMENTS","Bez komentarza");
define("_NESTED","Zagniedony");
define("_FLAT","Paski");
define("_THREAD","Wtek");
define("_OLDEST","Starsze jako pierwsze");
define("_NEWEST","Nowsze jako pierwsze");
define("_HIGHEST","Najpierw najwyej oceniane");
define("_COMMENTSWARNING","Komentarze s wasnoci ich twrcw. Nie ponosimy odpowiedzialnoci za ich tre.");
define("_SCORE","Wynik:");
define("_USERINFO","Informacje o uytkowniku");
define("_READREST","Przeczytaj dalszy cig komentarza...");
define("_REPLY","Odpowiedz na to");
define("_REPLYMAIN","Komentarz kocowy");
define("_NOSUBJECT","Bez tematu");
define("_NOANONCOMMENTS","Komentowanie niedozwolone dla anonimowego uytkownika, prosz si <a href=\"modules.php?name=Your_Account&amp;op=new_user\">zarejestrowa</a>");
define("_PARENT","Nadrzdny");
define("_ROOT","Root");
define("_UCOMMENT","Komentarz");
define("_ALLOWEDHTML","Dozwolony HTML:");
define("_POSTANON","Wylij anonimowo");
define("_EXTRANS","Zamiana (tagi html na tekst)");
define("_HTMLFORMATED","Formatowanie HTML");
define("_PLAINTEXT","Stary teskst bez formatowania");
define("_ONN","na...");
define("_SUBJECT","Temat");
define("_SURVEYCOM","Wylij komentarz");
define("_SURVEYCOMPRE","Przejrzyj komentarz");
define("_NOTRIGHT","Co jest nie tak ze zmienn w tej funkcji. Ta wiadomo ma wanie ustrzec Ci od bdw");
define("_DIRECTCOM","Bezporedni przegld komentarza...");
define("_SENDAMSG","Wylij wiadomo");
define("_PASTSURVEYS","Poprzednie ankiety");



define("_LVOTES","Gosw");
define("_TOTALVOTES","Razem gosw:");
define("_VOTING","Skrytka do gosowania");
define("_OTHERPOLLS","Inne ankiety");
define("_CURRENTSURVEY","Biece gosowanie");
define("_CURRENTPOLLRESULTS","Aktualny rezultat gosowania");
define("_PREVIEW","Podgld");
define("_REFRESH","Odwie");
define("_SURVEYS","Ankiety");
define("_ATTACHEDTOARTICLE","- dodana do artykuu:");
define("_SURVEYSATTACHED","Ankiety dodane do artykuw");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Surveys/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","Twoje imi i nazwisko");
define("_OK","Ok!");
define("_COMMENT","komentarz");
define("_CONFIGURE","Konfiguracja");
define("_LOGINCREATE","Logowanie/Zaoenie konta");
define("_THRESHOLD","Prg");
define("_NOCOMMENTS","Bez komentarza");
define("_NESTED","Zagniedony");
define("_FLAT","Paski");
define("_THREAD","Wtek");
define("_OLDEST","Starsze jako pierwsze");
define("_NEWEST","Nowsze jako pierwsze");
define("_HIGHEST","Najpierw najwyej oceniane");
define("_COMMENTSWARNING","Komentarze s wasnoci ich twrcw. Nie ponosimy odpowiedzialnoci za ich tre.");
define("_SCORE","Wynik:");
define("_USERINFO","Informacje o uytkowniku");
define("_READREST","Przeczytaj dalszy cig komentarza...");
define("_REPLY","Odpowiedz na to");
define("_REPLYMAIN","Komentarz kocowy");
define("_NOSUBJECT","Bez tematu");
define("_NOANONCOMMENTS","Komentowanie niedozwolone dla anonimowego uytkownika, prosz si <a href=\"modules.php?name=Your_Account&amp;op=new_user\">zarejestrowa</a>");
define("_PARENT","Nadrzdny");
define("_ROOT","Root");
define("_UCOMMENT","Komentarz");
define("_ALLOWEDHTML","Dozwolony HTML:");
define("_POSTANON","Wylij anonimowo");
define("_EXTRANS","Zamiana (tagi html na tekst)");
define("_HTMLFORMATED","Formatowanie HTML");
define("_PLAINTEXT","Stary teskst bez formatowania");
define("_ONN","na...");
define("_SUBJECT","Temat");
define("_SURVEYCOM","Wylij komentarz");
define("_SURVEYCOMPRE","Przejrzyj komentarz");
define("_NOTRIGHT","Co jest nie tak ze zmienn w tej funkcji. Ta wiadomo ma wanie ustrzec Ci od bdw");
define("_DIRECTCOM","Bezporedni przegld komentarza...");
define("_SENDAMSG","Wylij wiadomo");
define("_PASTSURVEYS","Poprzednie ankiety");



define("_LVOTES","Gosw");
define("_TOTALVOTES","Razem gosw:");
define("_VOTING","Skrytka do gosowania");
define("_OTHERPOLLS","Inne ankiety");
define("_CURRENTSURVEY","Biece gosowanie");
define("_CURRENTPOLLRESULTS","Aktualny rezultat gosowania");
define("_PREVIEW","Podgld");
define("_REFRESH","Odwie");
define("_SURVEYS","Ankiety");
define("_ATTACHEDTOARTICLE","- dodana do artykuu:");
define("_SURVEYSATTACHED","Ankiety dodane do artykuw");

?>
